from davidkhala.utils.syntax.path import home_resolve, delete
from paddlenlp import Taskflow


class Client:
    def __init__(self):
        self.options = {
            'task': 'information_extraction',
            'batch_size': 1,
            'model': 'paddlenlp/PP-UIE-0.5B',
            'precision': 'float32',
        }

    @staticmethod
    def clean():
        """clean up downloaded models on local disk"""
        delete(home_resolve('.paddlenlp', 'models'))

    def process(self, text: str, _schema: list[str]) -> list[dict]:
        ie = Taskflow(
            **self.options,
            schema=_schema
        )
        results = ie(text)
        assert len(results) == self.options['batch_size']
        return [{ k: [_['text'] for _ in v] for k, v in item.items()} for item in results ]





from pathlib import Path

from davidkhala.utils.syntax.path import home_resolve, delete


class Client:

    def init(self):
        from paddleocr import PaddleOCR
        self.all = PaddleOCR(use_doc_unwarping=True)
    @staticmethod
    def clean():
        """clean up downloaded models on local disk"""
        delete(home_resolve('.paddlex', 'official_models'))

    def process(self, file: Path) -> list[str]:
        results = self.all.predict(str(file))
        assert len(results) == 1
        return results[0]['rec_texts']



import base64
from abc import ABC, abstractmethod
from pathlib import Path


class Client(ABC):
    @staticmethod
    def _read(file: Path) -> str:
        with open(file, "rb") as f:
            content = base64.b64encode(f.read()).decode('utf-8')
        return content

    @abstractmethod
    def process(self, file: Path, **kwargs) -> list[dict] | dict: ...
